<?php
/*
Plugin Name: 推特功能插件
Plugin URI: https://your-plugin-uri.com/
Description: 实现推特功能，包括发布短语内容、时间信息和样式优化的推特列表。
Version: 1.0
Author: Your Name
Author URI: https://your-website.com/
*/

// 创建自定义数据库表格
function create_tweet_table() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'tweets';
    $charset_collate = $wpdb->get_charset_collate();
    $sql = "CREATE TABLE $table_name (
        id INT(11) NOT NULL AUTO_INCREMENT,
        content TEXT NOT NULL,
        time DATETIME NOT NULL,
        PRIMARY KEY (id)
    ) $charset_collate;";
    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
    dbDelta( $sql );
}
register_activation_hook( __FILE__, 'create_tweet_table' );

// 添加推特发布表单（仅作者可见）
if ( ! function_exists( 'tweet_form' ) ) {
    function tweet_form() {
        ob_start();
        if ( current_user_can( 'publish_posts' ) ) { // 仅作者可见
            ?>
            <form method="post" action="<?php echo esc_url( admin_url('admin-post.php') ); ?>">
                <input type="hidden" name="action" value="submit_tweet">
                <label for="tweet_content">内容：</label>
                <input type="text" name="tweet_content" id="tweet_content">
                <input type="submit" value="发布">
            </form>
            <?php
        }
        return ob_get_clean();
    }
}
add_shortcode( 'tweet_form', 'tweet_form' );

// 处理推特发布表单提交
function submit_tweet() {
    if ( isset( $_POST['tweet_content'] ) ) {
        $content = sanitize_text_field( $_POST['tweet_content'] );
        $time = current_time( 'mysql' );
        global $wpdb;
        $table_name = $wpdb->prefix . 'tweets';
        $wpdb->insert(
            $table_name,
            array(
                'content' => $content,
                'time' => $time
            )
        );
    }
    wp_redirect( esc_url( $_SERVER['HTTP_REFERER'] ) );
    exit;
}
add_action( 'admin_post_nopriv_submit_tweet', 'submit_tweet' );
add_action( 'admin_post_submit_tweet', 'submit_tweet' );

// 注册样式表
function enqueue_tweet_styles() {
    wp_enqueue_style( 'tweet-styles', plugins_url( 'tweet-styles.css', __FILE__ ) );
}
add_action( 'wp_enqueue_scripts', 'enqueue_tweet_styles' );

// 显示推特列表（样式优化）
function tweet_list() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'tweets';
    $tweets = $wpdb->get_results( "SELECT * FROM $table_name ORDER BY time DESC" );
    ob_start();
    if ( ! empty( $tweets ) ) {
        echo '<ul class="tweet-list">';
        foreach ( $tweets as $tweet ) {
            echo '<li class="tweet">';
            echo '<div class="tweet-content">' . esc_html( $tweet->content )
            . '</div>';
            echo '<div class="tweet-meta">发布于：'
            . esc_html( $tweet->time )
            . '</div>';
            echo '</li>';
        }
        echo '</ul>';
    } else {
        echo '<p>暂无推特内容。</p>';
    }
    return ob_get_clean();
}
add_shortcode( 'tweet_list', 'tweet_list' );
